@@ -22,17 +22,20 @@
 
 #include <KoFilter.h>
 #include <KoStore.h>
+//Added by qt3to4:
+#include <QByteArray>
 
-class DBaseImport : public KoFilter {
+class DBaseImport : public KoFilter
+{
 
     Q_OBJECT
 
 public:
 
-    DBaseImport ( QObject *parent, const char* name, const QStringList& );
+    DBaseImport(QObject *parent, const QStringList&);
     virtual ~DBaseImport() {}
 
-    virtual KoFilter::ConversionStatus convert( const QCString& from, const QCString& to );
+    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
 };
 
 #endif // __DBASEIMPORT_H
