@@ -39,10 +39,10 @@ private Q_SLOTS:
     void testUnary();
     void testBinary();
     void testOperators();
+    void testComparison();
     void testString();
     void testFunction();
     void testInlineArrays();
-    void testEquality();
 
 private:
     Value evaluate(const QString&, Value&);
