@@ -1,5 +1,5 @@
 /* This file is part of the KOffice project
- * Copyright (C) 2005,2008 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2005,2008,2010 Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,6 +20,7 @@
 
 #include <KWPageManager.h>
 #include <KWPage.h>
+#include <KoColorBackground.h>
 
 #include <kdebug.h>
 
@@ -593,6 +594,8 @@ void TestPageManager::testPadding()
     QCOMPARE(padding2.right, padding.right);
 
     KoPageLayout lay;
+    QVERIFY(lay.leftMargin >= 0);
+    QVERIFY(lay.bindingSide == -1);
     lay.width = 100;
     lay.height = 50;
     KWPageStyle style("testStyle");
@@ -639,5 +642,68 @@ void TestPageManager::testPageOffset()
     QCOMPARE(page.offsetInDocument(), (qreal) 400 * 49);
 }
 
+void TestPageManager::testBackgroundRefCount()
+{
+    KWPageStyle ps1("test");
+    QVERIFY(ps1.background() == 0);
+    KoColorBackground *background = new KoColorBackground(QColor(Qt::red));
+    QVERIFY(background->ref());
+    QCOMPARE(background->useCount(), 1);
+
+    ps1.setBackground(background);
+    QCOMPARE(background->useCount(), 2);
+
+    {
+        KWPageStyle ps2("test2");
+        QCOMPARE(background->useCount(), 2);
+        ps2 = ps1;
+        QCOMPARE(background->useCount(), 2);
+    }
+    QCOMPARE(background->useCount(), 2);
+
+    ps1 = ps1;
+    QCOMPARE(background->useCount(), 2);
+    ps1.setBackground(0);
+    QCOMPARE(background->useCount(), 1);
+    delete background;
+}
+
+void TestPageManager::testAppendPageSpread()
+{
+    KWPageManager manager;
+
+    KWPageStyle style = manager.addPageStyle("pagestyle1");
+    KoPageLayout layout = style.pageLayout();
+    layout.leftMargin = -1;
+    layout.rightMargin = -1;
+    layout.pageEdge = 7;
+    layout.bindingSide = 13;
+    style.setPageLayout(layout);
+
+    KWPage page1 = manager.appendPage(style);
+    QCOMPARE(page1.pageNumber(), 1);
+    QCOMPARE(page1.pageSide(), KWPage::Right);
+    QCOMPARE(page1.width(), style.pageLayout().width);
+
+    KWPage page2 = manager.appendPage(style);
+    QCOMPARE(page1.pageNumber(), 1);
+    QCOMPARE(page1.pageSide(), KWPage::Right);
+    QCOMPARE(page1.width(), style.pageLayout().width);
+    QCOMPARE(page2.pageNumber(), 2);
+    QCOMPARE(page2.pageSide(), KWPage::PageSpread);
+    QCOMPARE(page2.width(), style.pageLayout().width * 2);
+
+    KWPage page3 = manager.insertPage(2, style);
+    QCOMPARE(page1.pageNumber(), 1);
+    QCOMPARE(page1.pageSide(), KWPage::Right);
+    QCOMPARE(page1.width(), style.pageLayout().width);
+    QCOMPARE(page2.pageNumber(), 4);
+    QCOMPARE(page2.pageSide(), KWPage::PageSpread);
+    QCOMPARE(page2.width(), style.pageLayout().width * 2);
+    QCOMPARE(page3.pageNumber(), 2);
+    QCOMPARE(page3.pageSide(), KWPage::PageSpread);
+    QCOMPARE(page3.width(), style.pageLayout().width * 2);
+}
+
 QTEST_KDEMAIN(TestPageManager, GUI)
-#include "TestPageManager.moc"
+#include <TestPageManager.moc>
