@@ -30,8 +30,8 @@
 #include <kservice.h>
 #include <kcomponentdata.h>
 
-#include "KoUnit.h"
-#include "KoPageLayout.h"
+#include <KoUnit.h>
+#include <KoPageLayout.h>
 #include "komain_export.h"
 #include "KoGridData.h"
 #include "KoGuidesData.h"
@@ -46,8 +46,11 @@ class KoOdfWriteStore;
 class KoMainWindow;
 class KoView;
 class KoDocumentInfo;
+class KoDocumentRdf;
+class KoDocumentRdfBase;
 class KoOpenPane;
-class KoUndoStack;
+class KUndoStack;
+class KoTextEditor;
 
 class KoVersionInfo
 {
@@ -450,19 +453,6 @@ public:
      */
     virtual bool loadXML(const KoXmlDocument & doc, KoStore * store) = 0;
 
-    /**
-     *  Reimplement this method to load the contents of your %KOffice document,
-     *  from the XML document ("content.xml"). The styles have been parsed already,
-     *  you can find them in the odfStore.styles(). The store can be used
-     *  to load images and embedded documents.
-     */
-    virtual bool loadOdf(KoOdfReadStore & odfStore) = 0;
-
-    /**
-     *  Reimplement this method to save the contents of your %KOffice document,
-     *  using the ODF format.
-     */
-    virtual bool saveOdf(SavingContext & documentContext) = 0;
 
     /**
      *  Reimplement this to save the contents of the %KOffice document into
@@ -563,6 +553,19 @@ public:
      */
     KoDocumentInfo *documentInfo() const;
 
+    /**
+     * @return the Rdf metadata for this document.
+     * This method should only be used by code that links to
+     * the RDF system and needs full access to the KoDocumentRdf object.
+     * @see KoDocumentRdf
+     */
+    KoDocumentRdf *documentRdf() const;
+    /**
+     * @return the Rdf metadata for this document.
+     * @see KoDocumentRdf
+     */
+    KoDocumentRdfBase *documentRdfBase() const;
+
     /**
      * Appends the shell to the list of shells which show this
      * document as their root document.
@@ -716,7 +719,7 @@ public:
     /**
      * Sets the unit used to display all measures/distances.
      */
-    void setUnit(KoUnit u);
+    void setUnit(const KoUnit &unit);
 
     /**
      * Save the unit to the settings writer
@@ -782,7 +785,7 @@ public slots:
     /**
      * Returns the global undo stack
      */
-    KoUndoStack *undoStack();
+    KUndoStack *undoStack();
     /**
      * Adds a command to the undo stack and executes it by calling the redo() function.
      * @param command command to add to the undo stack
@@ -819,7 +822,7 @@ signals:
      * It is common to connect views to it, in order to change the displayed units
      * (e.g. in the rulers)
      */
-    void unitChanged(KoUnit);
+    void unitChanged(const KoUnit &unit);
 
     /**
      * Progress info while loading or saving. The value is in percents (i.e. a number between 0 and 100)
